@@ -96,8 +96,8 @@ KateBuildView::KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
     , m_filenameDetectorGccWorked(false)
     , m_newDirDetector(QStringLiteral("make\\[.+\\]: .+ `.*'"))
 {
-    KXMLGUIClient::setComponentName (QLatin1String("katebuild"), i18n ("Kate Build Plugin"));
-    setXMLFile(QLatin1String("ui.rc"));
+    KXMLGUIClient::setComponentName (QStringLiteral("katebuild"), i18n ("Kate Build Plugin"));
+    setXMLFile(QStringLiteral("ui.rc"));
 
     m_toolView  = mw->createToolView(plugin, QStringLiteral("kate_plugin_katebuildplugin"),
                                       KTextEditor::MainWindow::Bottom,
@@ -152,8 +152,7 @@ KateBuildView::KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
     m_buildUi.cancelBuildButton->setEnabled(false);
     m_buildUi.cancelBuildButton2->setEnabled(false);
 
-    connect(m_buildUi.errTreeWidget, &QTreeWidget::itemClicked,
-            this, &KateBuildView::slotErrorSelected);
+    connect(m_buildUi.errTreeWidget, &QTreeWidget::itemClicked, this, &KateBuildView::slotErrorSelected);
 
     m_buildUi.plainTextEdit->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
     m_buildUi.plainTextEdit->setReadOnly(true);
@@ -186,14 +185,12 @@ KateBuildView::KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
     m_win->guiFactory()->addClient(this);
 
     // watch for project plugin view creation/deletion
-    connect(m_win, &KTextEditor::MainWindow::pluginViewCreated,
-            this, &KateBuildView::slotPluginViewCreated);
+    connect(m_win, &KTextEditor::MainWindow::pluginViewCreated, this, &KateBuildView::slotPluginViewCreated);
+    connect(m_win, &KTextEditor::MainWindow::pluginViewDeleted, this, &KateBuildView::slotPluginViewDeleted);
 
-    connect(m_win, &KTextEditor::MainWindow::pluginViewDeleted,
-            this, &KateBuildView::slotPluginViewDeleted);
-    // update once project plugin state manually
-    m_projectPluginView = m_win->pluginView (QStringLiteral("kateprojectplugin"));
-    slotProjectMapChanged ();
+    // Connect signals from project plugin to our slots
+    m_projectPluginView = m_win->pluginView(QStringLiteral("kateprojectplugin"));
+    slotPluginViewCreated(QStringLiteral("kateprojectplugin"), m_projectPluginView);
 }
 
 
@@ -264,12 +261,17 @@ void KateBuildView::readSessionConfig(const KConfigGroup& cg)
     QModelIndex root = m_targetsUi->targetsModel.index(tmpIndex);
     QModelIndex cmdIndex = m_targetsUi->targetsModel.index(tmpCmd, 0, root);
     m_targetsUi->targetsView->setCurrentIndex(cmdIndex);
+
+    // Add project targets, if any
+    slotAddProjectTarget();
 }
 
 /******************************************************************/
 void KateBuildView::writeSessionConfig(KConfigGroup& cg)
 {
+    // Don't save project targets, is not our area of accountability
     m_targetsUi->targetsModel.deleteTargetSet(i18n("Project Plugin Targets"));
+
     QList<TargetModel::TargetSet> targets = m_targetsUi->targetsModel.targetSets();
 
     cg.writeEntry("NumTargets", targets.size());
@@ -302,6 +304,8 @@ void KateBuildView::writeSessionConfig(KConfigGroup& cg)
 
     cg.writeEntry(QStringLiteral("Active Target Index"), set);
     cg.writeEntry(QStringLiteral("Active Target Command"), setRow);
+
+    // Restore project targets, if any
     slotAddProjectTarget();
 }
 
@@ -321,7 +325,8 @@ void KateBuildView::slotNext()
 
     while (++i < itemCount) {
         item = m_buildUi.errTreeWidget->topLevelItem(i);
-        if (!item->text(1).isEmpty() && !item->isHidden()) {
+        // Search item which fit view settings and has desired data
+        if (!item->text(1).isEmpty() && !item->isHidden() && item->data(1, Qt::UserRole).toInt()) {
             m_buildUi.errTreeWidget->setCurrentItem(item);
             m_buildUi.errTreeWidget->scrollToItem(item);
             slotErrorSelected(item);
@@ -345,7 +350,8 @@ void KateBuildView::slotPrev()
 
     while (--i >= 0) {
         item = m_buildUi.errTreeWidget->topLevelItem(i);
-        if (!item->text(1).isEmpty() && !item->isHidden()) {
+        // Search item which fit view settings and has desired data
+        if (!item->text(1).isEmpty() && !item->isHidden() && item->data(1, Qt::UserRole).toInt()) {
             m_buildUi.errTreeWidget->setCurrentItem(item);
             m_buildUi.errTreeWidget->scrollToItem(item);
             slotErrorSelected(item);
@@ -357,23 +363,36 @@ void KateBuildView::slotPrev()
 /******************************************************************/
 void KateBuildView::slotErrorSelected(QTreeWidgetItem *item)
 {
+    // any view active?
+    if (!m_win->activeView()) {
+        return;
+    }
+
+    // Avoid garish highlighting of the selected line
+    m_win->activeView()->setFocus();
+
+    // Search the item where the data we need is stored
+    while (!item->data(1, Qt::UserRole).toInt()) {
+        item = m_buildUi.errTreeWidget->itemAbove(item);
+        if (!item) {
+            return;
+        }
+    }
+
     // get stuff
     const QString filename = item->data(0, Qt::UserRole).toString();
-    if (filename.isEmpty()) return;
+    if (filename.isEmpty()) {
+        return;
+    }
+
     const int line = item->data(1, Qt::UserRole).toInt();
     const int column = item->data(2, Qt::UserRole).toInt();
 
     // open file (if needed, otherwise, this will activate only the right view...)
     m_win->openUrl(QUrl::fromLocalFile(filename));
 
-    // any view active?
-    if (!m_win->activeView()) {
-        return;
-    }
-
     // do it ;)
     m_win->activeView()->setCursorPosition(KTextEditor::Cursor(line-1, column-1));
-    m_win->activeView()->setFocus();
 }
 
 
@@ -493,7 +512,12 @@ bool KateBuildView::startProcess(const QString &dir, const QString &command)
     // set working directory
     m_make_dir = dir;
     m_make_dir_stack.push(m_make_dir);
-    // FIXME check
+
+    if (!QFile::exists(m_make_dir)) {
+        KMessageBox::error(nullptr, i18n("Cannot run command: %1\nWork path does not exist: %2", command, m_make_dir));
+        return false;
+    }
+
     m_proc.setWorkingDirectory(m_make_dir);
     m_proc.setShellCommand(command);
     m_proc.start();
@@ -618,7 +642,7 @@ bool KateBuildView::buildCurrentTarget()
         buildCmd.replace(QStringLiteral("%d"), docFInfo.absolutePath());
     }
     m_filenameDetectorGccWorked = false;
-    m_currentlyBuildingTarget = QStringLiteral("%1: %2").arg(targetSet).arg(cmdName);
+    m_currentlyBuildingTarget = QStringLiteral("%1: %2").arg(targetSet, cmdName);
     m_buildCancelled = false;
     QString msg = i18n("Building target <b>%1</b> ...", m_currentlyBuildingTarget);
     m_buildUi.buildStatusLabel->setText(msg);
@@ -909,18 +933,18 @@ void KateBuildView::slotDisplayMode(int mode) {
 }
 
 /******************************************************************/
-void KateBuildView::slotPluginViewCreated (const QString &name, QObject *pluginView)
+void KateBuildView::slotPluginViewCreated(const QString &name, QObject *pluginView)
 {
     // add view
-    if (name == QLatin1String("kateprojectplugin")) {
+    if (pluginView && name == QLatin1String("kateprojectplugin")) {
         m_projectPluginView = pluginView;
-        slotProjectMapChanged ();
-        connect(pluginView, SIGNAL(projectMapChanged()), this, SLOT(slotProjectMapChanged()));
+        slotAddProjectTarget();
+        connect(pluginView, SIGNAL(projectMapChanged()), this, SLOT(slotProjectMapChanged()), Qt::UniqueConnection);
     }
 }
 
 /******************************************************************/
-void KateBuildView::slotPluginViewDeleted (const QString &name, QObject *)
+void KateBuildView::slotPluginViewDeleted(const QString &name, QObject *)
 {
     // remove view
     if (name == QLatin1String("kateprojectplugin")) {
@@ -930,7 +954,7 @@ void KateBuildView::slotPluginViewDeleted (const QString &name, QObject *)
 }
 
 /******************************************************************/
-void KateBuildView::slotProjectMapChanged ()
+void KateBuildView::slotProjectMapChanged()
 {
     // only do stuff with valid project
     if (!m_projectPluginView) {
